@@ -56,7 +56,7 @@ def miss_mechanism(dag, noise='MAR', rom=0.5):
             vars_miss2 = random.sample([x for x in varnames if x not in vars_miss + vars_comp], nom - len(vars_miss))
             vars_comp = [x for x in varnames if x not in vars_miss + vars_miss2]
             for var in vars_miss2:
-                nbr = adjacent(dag, var)
+                nbr = neighbours(dag, var)
                 if any(item in vars_comp for item in nbr):
                     cause_dict[var] = random.sample([x for x in nbr if x in vars_comp], 1)
                 else:
@@ -78,7 +78,7 @@ def miss_mechanism(dag, noise='MAR', rom=0.5):
             vars_miss2 = random.sample([x for x in varnames if x not in vars_miss], nom - len(vars_miss))
             vars_comp = [x for x in varnames if x not in vars_miss + vars_miss2]
             for var in vars_miss2:
-                nbr = adjacent(dag, var)
+                nbr = neighbours(dag, var)
                 if any(item not in vars_comp for item in nbr):
                     cause_dict[var] = random.sample([x for x in nbr if x not in vars_comp + [var]], 1)
                 else:
@@ -99,7 +99,7 @@ def vstructures(dag):
     for var in cpdag:
         if len(cpdag[var]['par']) > 1:
             for pair in [(a, b) for idx, a in enumerate(cpdag[var]['par']) for b in cpdag[var]['par'][idx + 1:]]:
-                if pair[0] not in adjacent(cpdag, pair[1]):
+                if pair[0] not in neighbours(cpdag, pair[1]):
                     vstructs.append([pair[0], var, pair[1]])
     return vstructs
 
